==> nextcloud-app-tasks-0.9.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/es_NI.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tareas",
    "Due yesterday" : "Venció ayer",
    "Due today" : "Vence hoy",
    "Due tomorrow" : "Vence mañana",
    "Due on" : "Vence el",
    "Started yesterday" : "Iniciado ayer",
    "Starts today" : "Inicia hoy",
    "Starts tomorrow" : "Inicia mañana",
    "Started on" : "Iniciado el",
    "Starts on" : "Inicia el",
    "[Remind me yesterday at ]HH:mm" : "[Recuérdame ayer a las ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Recuérdame hoy a las ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Recuérdame mañana a las ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Recuérdame el ]DD [de ]MMM [de ] YYYY,[ a las ]HH:mm",
    "Yesterday" : "Ayer",
    "Today" : "Hoy",
    "Tomorrow" : "Mañana",
    "in %s" : "en %s",
    "%s ago" : "hace %s",
    "seconds" : "segundos",
    "a minute" : "un minuto",
    "%d minutes" : "%d minutos",
    "an hour" : "una hora",
    "%d hours" : "%d horas",
    "a day" : "un día",
    "%d days" : "%d días",
    "a month" : "un mes",
    "%d months" : "%d meses",
    "a year" : "un año",
    "%d years" : "%d años",
    "week" : "semana",
    "weeks" : "semanas",
    "day" : "día",
    "days" : "días",
    "hour" : "hora",
    "hours" : "horas",
    "minute" : "minuto",
    "minutes" : "minutos",
    "second" : "segundo",
    "before beginning" : "antes de empezar",
    "after beginning" : "después de empezar",
    "before end" : "antes de terminar",
    "after end" : "después de terminar",
    "Comment" : "Comentario",
    "Add a comment" : "Agregar un comentario",
    "The name \"%s\" is already used." : "El nombre \"%s\" ya está en uso.",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Add an important item in \"%s\"..." : "Agregar un elemento importante en \"%s\"...",
    "Add an item due today in \"%s\"..." : "Agregar un elemento que vence hoy \"%s\"...",
    "Add an item in \"%s\"..." : "Agregar un elemento en \"%s\"...",
    "Add a current item in \"%s\"..." : "Agegar un elemento actual en \"%s\"...",
    "Add a subtask to \"%s\"..." : "Agregar una subtarea a \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
    "Hours" : "Horas",
    "Minutes" : "Minutos",
    "Set due date" : "Establecer fecha de vencimiento",
    "%s %% completed" : "%s %% terminado",
    "priority %s: " : "prioridad %s:",
    "high" : "alto",
    "medium" : "medio",
    "low" : "bajo",
    "no priority assigned" : "no hay alguna prioridad asignada",
    "Remind me" : "Recuérdame",
    "at the end" : "al final",
    "at the beginning" : "al inicio",
    "Set start date" : "Establecer fecha de inicio",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Unnamed" : "Sin nombre",
    "Important" : "Importante",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Delete" : "Borrar",
    "Cancel" : "Cancelar",
    "Edit" : "Editar",
    "Link" : "Liga",
    "Download" : "Descargar",
    "Save" : "Guardar",
    "Add List..." : "Agregar Lista...",
    "New List" : "Nueva Lista",
    "Settings" : "Configuraciones ",
    "Start of week" : "Inicio de semana",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Default" : "Predeterminado",
    "Due date" : "Fecha de vencimiento",
    "Start date" : "Fecha de inicio",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Load remaining completed tasks." : "Cargar las tareas terminadas restantes. ",
    "Task is completed" : "La tarea ha sido completada",
    "All day" : "Todo el día",
    "(New category)" : "(Categoría nueva)",
    "Select categories..." : "Seleccionar categorías...",
    "Loading the task..." : "Cargando la tarea...",
    "Task not found!" : "¡Tarea no encontrada!",
    "add a subtask to" : "agregar una subtarea a",
    "Toggle subtasks" : "Alternar subtareas",
    "Toggle completed subtasks" : "Alternar subtareas completadas"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.13.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/es_NI.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Importante",
    "Today" : "Hoy",
    "Week" : "Semana",
    "All" : "Todos",
    "Current" : "Actual",
    "Completed" : "Completado",
    "Tasks" : "Tareas",
    "New List" : "Nueva Lista",
    "Cancel" : "Cancelar",
    "Save" : "Guardar",
    "An empty name is not allowed." : "No se permite un nombre vacío.",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "can edit" : "puede editar",
    "Edit" : "Editar",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Unshare" : "Dejar de compartir",
    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
    "Hidden" : "Oculto",
    "Visible" : "Visible",
    "Automatic" : "Automático",
    "Change sort order" : "Cambiar el criterio para ordenar",
    "Start date" : "Fecha de inicio",
    "Due date" : "Fecha de vencimiento",
    "Last modified" : "Última modificación",
    "Priority" : "Prioridad",
    "Alphabetically" : "Alfabéticamente",
    "Manually" : "Manualmente",
    "Task is completed" : "La tarea ha sido completada",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
    "Tomorrow" : "Mañana",
    "Set start date" : "Establecer fecha de inicio",
    "Set due date" : "Establecer fecha de vencimiento",
    "All day" : "Todo el día",
    "Task not found!" : "¡Tarea no encontrada!",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento "
},
"nplurals=2; plural=(n != 1);");
